==> fr-aster-9.3.0.1.tbz: aster/STA9.3/bibpyt/Messages/algeline5.py <==
#@ MODIF algeline5 Messages  DATE 26/05/2008   AUTEUR BOITEAU O.BOITEAU 
# -*- coding: iso-8859-1 -*-

#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg={

4: _("""
 erreur LAPACK (ou BLAS) au niveau de la routine  %(k1)s
  le paramtre numro  %(i1)d
  n'a pas une valeur cohrente %(i2)d
"""),

5: _("""
 !! Attention, vous utilisez l'option de test FETI de l'interface.
 On va donc simuler la rsolution d'un systme diagonal canonique,
 pour provoquer un test d'ensemble de l'algorithme qui doit trouver
 la solution U=1 sur tous les noeuds.
 Vos rsultats sont donc articiellement fausss pour les besoins de
 ce test. Pour raliser effectivement votre calcul, dsactiver cette
 option (INFO_FETI(12:12)='F' au lieu de 'T') !!
"""),

6: _("""
 Rsolution MULTI_FRONTALE :
 problme dans le traitement des rsultats de AMDBAR
 tous les NDS du SN %(i1)d ont NV nul
"""),

10: _("""
 ! le nb de noeuds de la structure   :  %(i1)d
 ! la base utilise est              :  %(k1)s
 ! les caractristiques lmentaires :  %(k2)s
 ! diamtre de la structure          :  %(r1)f
 ! type de pas                       :  %(i2)d
 ----------------------------------------------
"""),

11: _("""
 ! le profil de vitesse de la zone:  %(k1)s
 !   type de rseau de la zone    :  %(i1)d
 ----------------------------------------------
"""),

12: _("""

"""),

13: _("""
 ! le noeud d'application           :  %(k1)s
 ! la base utilise est             :  %(k2)s
 ! les caractristiques lmentaires:  %(k3)s
 ! diamtre de la structure         :  %(r1)f
 ! type de configuration            :  %(k4)s
 ! le coefficient de masse ajoute  :  %(r2)f
 ! le profil de masse volumique     :  %(r3)f
 ----------------------------------------------

"""),

14: _("""
    pas de couplage pris en compte
 ----------------------------------------------
"""),

15: _("""
   pour le concept  %(k1)s  le mode numro  %(i1)d
"""),

16: _("""
  de frequence  %(r1)f
"""),

17: _("""
  de charge critique  %(r1)f
"""),

18: _("""
  a une norme d'erreur de  %(r1)f  suprieure au seuil admis  %(r2)f
"""),

19: _("""
   pour le concept  %(k1)s  le mode numro  %(i1)d
"""),

20: _("""
  de frquence  %(r1)f
  est en dehors de l'intervalle de recherche : %(r2)f
  ,  %(r3)f
"""),

21: _("""
  de charge critique  %(r1)f
  est en dehors de l'intervalle de recherche : %(r2)f
  ,  %(r3)f
"""),

22: _("""

"""),

23: _("""
   pour le concept  %(k1)s
"""),

24: _("""
  dans l'intervalle  ( %(r1)f  ,  %(r2)f )
  il y a thoriquement  %(i1)d frequence(s)
  et on en a calcul  %(i2)d
"""),

25: _("""
  dans l'intervalle  ( %(r1)f  ,  %(r2)f )
  il y a thoriquement  %(i1)d charge(s) critique(s)
  et on en a calcul  %(i2)d
"""),

26: _("""

"""),

27: _("""
 la valeur du shift %(r1)f  est une frquence propre
"""),

28: _("""
 les nombres de termes des matrices RIGI et MASSE diffrent
 celui de la matrice MASSE vaut :  %(i1)d
 celui de la matrice RIGI  vaut :  %(i2)d

"""),

29: _("""
 le nombre d'amortissements reduits est trop grand
 le nombre de modes propres vaut  %(i1)d
 et le nombre de coefficients :   %(i2)d
 on ne garde donc que les %(i3)d premiers coefficients

"""),

30: _("""
 le nombre d'amortissements rduits est insuffisant, il en manque :  %(i1)d,
 car le nombre de modes vaut :  %(i2)d
 on rajoute  %(i3)d amortissements rduits avec la valeur du dernier mode propre.
"""),

31: _("""
  incoherence :
   DEEQ I      =  %(i1)d
   DEEQ(2*I-1) =  %(i2)d
   DEEQ(2*I)   =  %(i3)d

"""),

32: _("""
  erreur de type DELG(IDDL) diffrent de -1 ou -2  %(i1)d
"""),

33: _("""
 un ddl bloqu a au moins 2 LAMBDA1 ou 2 LAMBDA2
 le ddl bloqu est  %(i1)d

"""),

34: _("""
 incohrence des lagranges
 DDL %(i1)d
 LAMBDA1 %(i2)d
 LAMBDA1 %(i3)d
"""),

35: _("""
 erreur programmeur
 le LAMBDA2  %(i1)d a moins de 2 voisins
 il faut le LAMBDA1 et au moins un DDL

"""),

36: _("""
 Problme dans le calcul des DDL :
 NUM devrait etre gal  n1 :
 num = %(i1)d , n1 = %(i2)d
 impression des lagranges
"""),

37: _("""
 NUME_DDL incohrence des lagranges
  ddl     %(i1)d
  lambda1 %(i2)d
  lambda1 %(i3)d
"""),

38: _("""
 nombre de relations linaires %(i1)d
"""),

39: _("""
 LAMBDA1 de R linaire : %(i1)d
 LAMBDA2 de R linaire : %(i2)d
"""),

40: _("""
 Donnes errones
"""),

41: _("""
 pas de mode statique pour  le noeud :  %(k1)s  et sa composante :  %(k2)s

"""),

42: _("""
 pour les modes statiques :
 on attend un :  %(k1)s
 noeud :  %(k2)s
 cmp   :  %(k3)s

"""),

43: _("""
 champ inexistant.
 champ :  %(k1)s
 noeud :  %(k2)s
 cmp   :  %(k3)s

"""),

48: _("""
 incohrence de certains paramtres modaux propres  ARPACK
  numro d'erreur  %(i1)d

"""),

49: _("""
 nombre de valeurs propres converges  %(i1)d < nombre de frquences demandes  %(i2)d
 erreur ARPACK numro :  %(i3)d
 --> le calcul continue, la prochaine fois
 -->   augmenter DIM_SOUS_ESPACE =  %(i4)d
 -->   ou NMAX_ITER_SOREN =  %(i5)d
 -->   ou PREC_SOREN =  %(r1)f

"""),

51: _("""
 la valeur propre numro  %(i1)d a une partie imaginaire non nulle
 re(vp) = %(r1)f
 im(vp) = %(r2)f
 --> ce phnomne numrique est frquent
 --> sur les premires valeurs propres
 --> lorsque le spectre recherche est
 --> tres tendu (en pulsation)

"""),

52: _("""
 LAIGLE: Erreur
   - Non convergence  l'itration maxi : %(i1)d
   - Convergence irrgulire & erreur >   %(r1)f
   - Diminuer la taille d'incrment.
"""),

53: _("""
 Erreur de programmation MULT_FRONT (NUME_DDL / PREML0) :
   * Sur-connexion des Lagranges Lambda1
"""),

54: _("""
     ==== Type de maille Aster / Type de maille GMSH ====
"""),

55: _("""
    %(i1)d  lments %(k1)s dcoups en %(i2)d  lments %(k2)s a %(i3)d noeuds
"""),

56: _("""
    La matrice factorise produit par l'oprateur FACTOR ne peut faire l'objet
    d'un concept rentrant car la mthode de rsolution dfinie dans NUME_DDL
    est 'GCPC'.
"""),

57: _("""
    Le prconditionnement d'une matrice assemble complexe n'est pas permis.
"""),

58: _("""
    La masse du modele est nulle. On ne peut normer par rapport a la masse.
"""),

59: _("""
 MULT_FRONT: Erreur dans la renumerotation
   - Le Super-Noeud : %(i1)d
   - devrait etre le fils de   %(i2)d

 Risques & conseils :
   - Vous devriez rencontrer des problmes lors de la factorisation.
   - Essayez un autre algorithme pour la renumrotation : 'MD', 'MDA', ...
"""),

60: _("""
    Mthode QZ dans MODE_ITER_SIMULT: La variante QR ne fonctionne qu'avec une
    matrice B symtrique dfinie positive ! Donc elle n'accepte pas le flambement,
    les Lagranges d'AFFE_CHAR_MECA, une matrice de rigidit complexe ou les
    problmes modaux quadratiques.
"""),
61: _("""
    Mthode QZ dans MODE_ITER_SIMULT: proprit spectrale non respecte sur la
    valeur propre n %(i1)d !. On a pas |alpha| < ||A|| et |bta| < ||B|| 
                     |alpha|=%(r1)f, ||A||=%(r2)f
                     | bta|=%(r3)f, ||B||=%(r4)f
"""),
62: _("""
    Mthode QZ dans MODE_ITER_SIMULT: On trouve un nombre de valeurs propres 
    %(i1)d diffrent du nombre de ddls physiques actifs %(i2)d ! 
"""),
63: _("""
    Mthode QZ dans MODE_ITER_SIMULT + OPTION='BANDE': On trouve un nombre de 
    valeurs propres %(i1)d diffrent du nombre de valeurs propres dtectes
    dans la bande %(i2)d ! 
"""),
64: _("""
    Problme modal quadratique et mthode de JACOBI sont incompatible !
    Essayer plutt la mthode de SORENSEN (METHODE='SORENSEN'). 
"""),
65: _("""
    L'option de calcul 'TOUT' n'est licite qu'avec METHODE='QZ'! 
"""),
66: _("""
    Mthode QZ dans MODE_ITER_SIMULT : On souhaite un nombre de valeurs
    propres %(i1)d suprieur au nombre de valeurs propres dtectes %(i2)d ! 
"""),
67: _("""
    Attention on souhaite un nombre de valeurs propres NMAX_FREQ=%(i1)d suprieur
    au nombre de valeurs propres dtectes NCONV=%(i2)d !
    Pour poursuivre le calcul on impose NMAX_FREQ=NCONV.
    Sans doute est-ce du  un mauvais tri dans les valeurs propres complexes
     conjugues. Contacter l'quipe de dveloppement.
"""),
68: _("""
    Mthode QZ dans MODE_ITER_SIMULT: erreur LAPACK %(i1)d !
"""),
}

==> fr-aster-9.4.0.2.tbz: aster/STA9.4/bibpyt/Messages/algeline5.py <==
#@ MODIF algeline5 Messages  DATE 21/10/2008   AUTEUR NISTOR I.NISTOR 
# -*- coding: iso-8859-1 -*-

#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg={

4: _("""
 erreur LAPACK (ou BLAS) au niveau de la routine  %(k1)s
  le paramtre numro  %(i1)d
  n'a pas une valeur cohrente %(i2)d
"""),

5: _("""
 !! Attention, vous utilisez l'option de test FETI de l'interface.
 On va donc simuler la rsolution d'un systme diagonal canonique,
 pour provoquer un test d'ensemble de l'algorithme qui doit trouver
 la solution U=1 sur tous les noeuds.
 Vos rsultats sont donc articiellement fausss pour les besoins de
 ce test. Pour raliser effectivement votre calcul, dsactiver cette
 option (INFO_FETI(12:12)='F' au lieu de 'T') !!
"""),

6: _("""
 Rsolution MULTI_FRONTALE :
 problme dans le traitement des rsultats de AMDBAR
 tous les NDS du SN %(i1)d ont NV nul
"""),

10: _("""
 ! le nb de noeuds de la structure   :  %(i1)d
 ! la base utilise est              :  %(k1)s
 ! les caractristiques lmentaires :  %(k2)s
 ! diamtre de la structure          :  %(r1)f
 ! type de pas                       :  %(i2)d
 ----------------------------------------------
"""),

11: _("""
 ! le profil de vitesse de la zone:  %(k1)s
 !   type de rseau de la zone    :  %(i1)d
 ----------------------------------------------
"""),

12: _("""

"""),

13: _("""
 ! le noeud d'application           :  %(k1)s
 ! la base utilise est             :  %(k2)s
 ! les caractristiques lmentaires:  %(k3)s
 ! diamtre de la structure         :  %(r1)f
 ! type de configuration            :  %(k4)s
 ! le coefficient de masse ajoute  :  %(r2)f
 ! le profil de masse volumique     :  %(r3)f
 ----------------------------------------------

"""),

14: _("""
    pas de couplage pris en compte
 ----------------------------------------------
"""),

15: _("""
   pour le concept  %(k1)s  le mode numro  %(i1)d
"""),

16: _("""
  de frequence  %(r1)f
"""),

17: _("""
  de charge critique  %(r1)f
"""),

18: _("""
  a une norme d'erreur de  %(r1)f  suprieure au seuil admis  %(r2)f
"""),

19: _("""
   pour le concept  %(k1)s  le mode numro  %(i1)d
"""),

20: _("""
  de frquence  %(r1)f
  est en dehors de l'intervalle de recherche : %(r2)f
  ,  %(r3)f
"""),

21: _("""
  de charge critique  %(r1)f
  est en dehors de l'intervalle de recherche : %(r2)f
  ,  %(r3)f
"""),

22: _("""

"""),

23: _("""
   pour le concept  %(k1)s
"""),

24: _("""
  dans l'intervalle  ( %(r1)f  ,  %(r2)f )
  il y a thoriquement  %(i1)d frequence(s)
  et on en a calcul  %(i2)d
"""),

25: _("""
  dans l'intervalle  ( %(r1)f  ,  %(r2)f )
  il y a thoriquement  %(i1)d charge(s) critique(s)
  et on en a calcul  %(i2)d
"""),

26: _("""

"""),

27: _("""
 la valeur du shift %(r1)f  est une frquence propre
"""),

28: _("""
 les nombres de termes des matrices RIGI et MASSE diffrent
 celui de la matrice MASSE vaut :  %(i1)d
 celui de la matrice RIGI  vaut :  %(i2)d

"""),

29: _("""
 le nombre d'amortissements reduits est trop grand
 le nombre de modes propres vaut  %(i1)d
 et le nombre de coefficients :   %(i2)d
 on ne garde donc que les %(i3)d premiers coefficients

"""),

30: _("""
 le nombre d'amortissements rduits est insuffisant, il en manque :  %(i1)d,
 car le nombre de modes vaut :  %(i2)d
 on rajoute  %(i3)d amortissements rduits avec la valeur du dernier mode propre.
"""),

31: _("""
  incoherence :
   DEEQ I      =  %(i1)d
   DEEQ(2*I-1) =  %(i2)d
   DEEQ(2*I)   =  %(i3)d

"""),

32: _("""
  erreur de type DELG(IDDL) diffrent de -1 ou -2  %(i1)d
"""),

33: _("""
 un ddl bloqu a au moins 2 LAMBDA1 ou 2 LAMBDA2
 le ddl bloqu est  %(i1)d

"""),

34: _("""
 incohrence des lagranges
 DDL %(i1)d
 LAMBDA1 %(i2)d
 LAMBDA1 %(i3)d
"""),

35: _("""
 erreur programmeur
 le LAMBDA2  %(i1)d a moins de 2 voisins
 il faut le LAMBDA1 et au moins un DDL

"""),

36: _("""
 Problme dans le calcul des DDL :
 NUM devrait etre gal  n1 :
 num = %(i1)d , n1 = %(i2)d
 impression des lagranges
"""),

37: _("""
 NUME_DDL incohrence des lagranges
  ddl     %(i1)d
  lambda1 %(i2)d
  lambda1 %(i3)d
"""),

38: _("""
 nombre de relations linaires %(i1)d
"""),

39: _("""
 LAMBDA1 de R linaire : %(i1)d
 LAMBDA2 de R linaire : %(i2)d
"""),

40: _("""
 Donnes errones
"""),

41: _("""
 pas de mode statique pour  le noeud :  %(k1)s  et sa composante :  %(k2)s

"""),

42: _("""
 pour les modes statiques :
 on attend un :  %(k1)s
 noeud :  %(k2)s
 cmp   :  %(k3)s

"""),

43: _("""
 champ inexistant.
 champ :  %(k1)s
 noeud :  %(k2)s
 cmp   :  %(k3)s

"""),

48: _("""
 incohrence de certains paramtres modaux propres  ARPACK
  numro d'erreur  %(i1)d

"""),

49: _("""
 nombre de valeurs propres converges  %(i1)d < nombre de frquences demandes  %(i2)d
 erreur ARPACK numro :  %(i3)d
 --> le calcul continue, la prochaine fois
 -->   augmenter DIM_SOUS_ESPACE =  %(i4)d
 -->   ou NMAX_ITER_SOREN =  %(i5)d
 -->   ou PREC_SOREN =  %(r1)f

"""),

51: _("""
 la valeur propre numro  %(i1)d a une partie imaginaire non nulle
 re(vp) = %(r1)f
 im(vp) = %(r2)f
 --> ce phnomne numrique est frquent
 --> sur les premires valeurs propres
 --> lorsque le spectre recherche est
 --> tres tendu (en pulsation)

"""),

52: _("""
 LAIGLE: Erreur
   - Non convergence  l'itration maxi : %(i1)d
   - Convergence irrgulire & erreur >   %(r1)f
   - Diminuer la taille d'incrment.
"""),

53: _("""
 Erreur de programmation MULT_FRONT (NUME_DDL / PREML0) :
   * Sur-connexion des Lagranges Lambda1
"""),

54: _("""
     ==== Type de maille Aster / Type de maille GMSH ====
"""),

55: _("""
    %(i1)d  lments %(k1)s dcoups en %(i2)d  lments %(k2)s a %(i3)d noeuds
"""),

56: _("""
    La matrice factorise produit par l'oprateur FACTOR ne peut faire l'objet
    d'un concept rentrant car la mthode de rsolution dfinie dans NUME_DDL
    est 'GCPC'.
"""),

57: _("""
    Le prconditionnement d'une matrice assemble complexe n'est pas permis.
"""),

58: _("""
    La masse du modele est nulle. On ne peut normer par rapport a la masse.
"""),

59: _("""
 MULT_FRONT: Erreur dans la renumerotation
   - Le Super-Noeud : %(i1)d
   - devrait etre le fils de   %(i2)d

 Risques & conseils :
   - Vous devriez rencontrer des problmes lors de la factorisation.
   - Essayez un autre algorithme pour la renumrotation : 'MD', 'MDA', ...
"""),

60: _("""
    Mthode QZ dans MODE_ITER_SIMULT: La variante QR ne fonctionne qu'avec une
    matrice A symtrique relle et B symtrique relle dfinie positive ! 
    Donc elle n'accepte pas le flambement, les Lagranges d'AFFE_CHAR_MECA, 
    une matrice de rigidit/de masse complexe ou non symtrique, ainsi que les
    problmes modaux quadratiques.
"""),
61: _("""
    Mthode QZ dans MODE_ITER_SIMULT: proprit spectrale non respecte sur la
    valeur propre n %(i1)d !. On a pas |alpha| < ||A|| et |bta| < ||B|| 
                     |alpha|=%(r1)f, ||A||=%(r2)f
                     | bta|=%(r3)f, ||B||=%(r4)f
"""),
62: _("""
    Mthode QZ dans MODE_ITER_SIMULT: On trouve un nombre de valeurs propres 
    %(i1)d diffrent du nombre de ddls physiques actifs %(i2)d ! 
"""),
63: _("""
    Mthode QZ dans MODE_ITER_SIMULT + OPTION='BANDE': On trouve un nombre de 
    valeurs propres %(i1)d diffrent du nombre de valeurs propres dtectes
    dans la bande %(i2)d ! 
"""),
64: _("""
    Problme modal quadratique et mthode de JACOBI sont incompatible !
    Essayer plutt la mthode de SORENSEN (METHODE='SORENSEN'). 
"""),
65: _("""
    L'option de calcul 'TOUT' n'est licite qu'avec METHODE='QZ'! 
"""),
66: _("""
    Mthode QZ dans MODE_ITER_SIMULT : On souhaite un nombre de valeurs
    propres %(i1)d suprieur au nombre de valeurs propres dtectes %(i2)d ! 
"""),
67: _("""
    Attention on souhaite un nombre de valeurs propres NMAX_FREQ=%(i1)d suprieur
    au nombre de valeurs propres dtectes NCONV=%(i2)d !
    Pour poursuivre le calcul on impose NMAX_FREQ=NCONV.
    Sans doute est-ce du, soit:
     - un mauvais tri dans les valeurs propres complexes conjugues.
      Contacter l'quipe de dveloppement.
     - une mauvaise convergence de la mthode. Regarder les paramtres permettant
      d'amliorer celle-ci.
     - une action incomplte du shift. En diminuant la valeur de l'option CENTRE
      (FREQ) et en augmentant le nombre de valeurs propres retenues (NMAX_FREQ) on
      peut souvent capter tous les couples (lambda,conjg(lambda)) souhaits.
      Sinon utiliser METHODE='QZ' pour les problmes de petites tailles (<500 ddls).
"""),
68: _("""
    Mthode QZ dans MODE_ITER_SIMULT: erreur LAPACK %(i1)d !
"""),
69: _("""
    Matrices de raideur, de masse et/ou d'amortissement non symtrique(s) dans
    MODE_ITER_SIMULT. Pour l'instant, seules les mthodes QZ et SORENSEN 
    acceptent ce type de matrice.
    La mthode QZ est  rserver aux petits problmes modaux (centaines de ddls)
    dont on souhaite connaitre une grosse partie du spectre.
"""),
70: _("""
    Matrices de  raideur, de masse et/ou d'amortissement non symtrique(s) dans
    MODE_ITER_SIMULT avec,une matrice de raideur complexe. 
    Pour l'instant, ce cas n'a pas t pris en compte.
"""),
71: _("""
    Les deux bases ne sont pas du mme type (Complexe/Rel) !
"""),
}
